@@ -1,5 +1,5 @@
 package WWW::Google::Contacts;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 # ABSTRACT: Google Contacts Data API
 
@@ -222,8 +222,7 @@ sub create_group {
     my %headers = $self->{authsub}->auth_params;
     $headers{'Content-Type'}  = 'application/atom+xml';
     $headers{'GData-Version'} = $self->{'GData-Version'};
-    my $url =
-      'http://www.google.com/m8/feeds/groups/faylandblog%40gmail.com/full';
+    my $url = 'http://www.google.com/m8/feeds/groups/default/full';
     my $resp = $self->{ua}->post( $url, %headers, Content => $xml );
     print $resp->content . "\n" if $self->{debug};
     return ( $resp->code == 201 ) ? 1 : 0;
@@ -258,7 +257,7 @@ WWW::Google::Contacts - Google Contacts Data API
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
